@@ -307,7 +307,7 @@ def get_report_structure(config: Settings, summary: dict) -> Root:
         pbar.update()
 
     footer = HTML(
-        content='Report generated with <a href="https://github.com/pandas-profiling/pandas-profiling">pandas-profiling</a>.'
+        content='Report generated by <a href="https://ydata.ai/?utm_source=opensource&utm_medium=pandasprofiling&utm_campaign=report">YData</a>.'
     )
 
     return Root("Root", sections, footer)
