@@ -11,6 +11,9 @@ from pandas_profiling.report.structure.variables.render_generic import render_ge
 from pandas_profiling.report.structure.variables.render_image import render_image
 from pandas_profiling.report.structure.variables.render_path import render_path
 from pandas_profiling.report.structure.variables.render_real import render_real
+from pandas_profiling.report.structure.variables.render_timeseries import (
+    render_timeseries,
+)
 from pandas_profiling.report.structure.variables.render_url import render_url
 
 __all__ = [
@@ -25,5 +28,6 @@ __all__ = [
     "render_image",
     "render_path",
     "render_real",
+    "render_timeseries",
     "render_url",
 ]
