@@ -20,7 +20,7 @@ from pandas_profiling.report.presentation.core import (
 from pandas_profiling.report.presentation.core.renderable import Renderable
 from pandas_profiling.report.presentation.frequency_table_utils import freq_table
 from pandas_profiling.report.structure.variables.render_common import render_common
-from pandas_profiling.visualisation.plot import histogram, pie_plot
+from pandas_profiling.visualisation.plot import cat_frequency_plot, histogram
 
 
 def render_categorical_frequency(
@@ -392,19 +392,20 @@ def render_categorical(config: Settings, summary: dict) -> dict:
     if length:
         string_items.append(length_histo)
 
-    max_unique = config.plot.pie.max_unique
-    if max_unique > 0 and summary["n_distinct"] <= max_unique:
+    show = config.plot.cat_freq.show
+    max_unique = config.plot.cat_freq.max_unique
+
+    if show and (max_unique > 0) and (summary["n_distinct"] <= max_unique):
         string_items.append(
             Image(
-                pie_plot(
+                cat_frequency_plot(
                     config,
                     summary["value_counts_without_nan"],
-                    legend_kws={"loc": "upper right"},
                 ),
                 image_format=image_format,
-                alt="Pie chart",
-                name="Pie chart",
-                anchor_id=f"{varid}pie_chart",
+                alt="Category Frequency Plot",
+                name="Category Frequency Plot",
+                anchor_id=f"{varid}cat_frequency_plot",
             )
         )
 
